"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HttpFunctionApiController = void 0;
const api_1 = require("@mcma/api");
const uuid_1 = require("uuid");
const core_1 = require("@mcma/core");
function asStringMap(obj) {
    const copy = {};
    for (const key of Object.keys(obj)) {
        const val = obj[key];
        if (Array.isArray(val)) {
            copy[key] = val.join(",");
        }
        else if (typeof val === "object") {
            copy[key] = JSON.stringify(val);
        }
        else {
            copy[key] = val;
        }
    }
    return copy;
}
class HttpFunctionApiController {
    constructor(routes, loggerProvider, configVariables = core_1.ConfigVariables.getInstance()) {
        this.loggerProvider = loggerProvider;
        this.configVariables = configVariables;
        this.mcmaApiController = new api_1.McmaApiController(routes);
    }
    async handleRequest(request, response) {
        const requestContext = new api_1.McmaApiRequestContext(new api_1.McmaApiRequest({
            id: uuid_1.v4(),
            path: request.path,
            httpMethod: request.method,
            headers: asStringMap(request.headers),
            pathVariables: {},
            queryStringParameters: asStringMap(request.query),
            body: request.body
        }), this.loggerProvider, this.configVariables);
        await this.mcmaApiController.handleRequest(requestContext);
        response.statusCode = requestContext.response.statusCode;
        response.statusMessage = requestContext.response.statusMessage;
        for (const header in requestContext.response.headers) {
            response.setHeader(header, requestContext.response.headers[header]);
        }
        response.send(requestContext.response.body);
    }
}
exports.HttpFunctionApiController = HttpFunctionApiController;
